from setuptools import setup

setup(name='gaussian_binomial_dist_package',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gaussian_binomial_dist_package'],
      author='Samuel K',
      author_email='samuelkabelo1@gmail.com',
      zip_safe=False)
